import { useState, useEffect } from "react";
import { Button } from "@/components/ui/button";
import { Menu, X } from "lucide-react";
import AdBanner from "@/components/ads/AdBanner";

export default function Header() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);

  const scrollToSection = (sectionId: string) => {
    const element = document.getElementById(sectionId);
    if (element) {
      const offsetTop = element.offsetTop - 80; // Account for fixed header
      window.scrollTo({
        top: offsetTop,
        behavior: "smooth"
      });
    }
    setIsMenuOpen(false);
  };

  return (
    <header className="bg-white/10 backdrop-blur-md border-b border-white/20 sticky top-0 z-50" role="banner">
      <nav className="container mx-auto px-4 py-2 sm:py-4" aria-label="Main navigation">
        <div className="flex items-center justify-between">
          <div className="flex items-center space-x-2">
            <div className="w-8 h-8 bg-gradient-to-br from-pink-500 to-purple-500 rounded-lg flex items-center justify-center" aria-hidden="true">
              <span className="text-white font-bold text-sm">T</span>
            </div>
            <h1 className="text-xl font-bold text-white">Tiktok Downloader</h1>
          </div>
          
          {/* Desktop Navigation */}
          <div className="hidden md:flex items-center space-x-8" role="navigation" aria-label="Desktop navigation">
            <button
              onClick={() => scrollToSection("home")}
              className="text-white/90 hover:text-white transition-colors"
            >
              Home
            </button>
            <button
              onClick={() => scrollToSection("features")}
              className="text-white/90 hover:text-white transition-colors"
            >
              Features
            </button>
            <button
              onClick={() => scrollToSection("how-it-works")}
              className="text-white/90 hover:text-white transition-colors"
            >
              How It Works
            </button>
            <button
              onClick={() => scrollToSection("about")}
              className="text-white/90 hover:text-white transition-colors"
            >
              About
            </button>
            <button
              onClick={() => scrollToSection("blog")}
              className="text-white/90 hover:text-white transition-colors"
            >
              Blog
            </button>
            <button
              onClick={() => scrollToSection("faq")}
              className="text-white/90 hover:text-white transition-colors"
            >
              FAQ
            </button>
          </div>

          {/* Mobile Menu Button */}
          <Button
            variant="ghost"
            size="icon"
            onClick={() => setIsMenuOpen(!isMenuOpen)}
            className="md:hidden text-white hover:bg-white/10"
            aria-label={isMenuOpen ? "Close menu" : "Open menu"}
            aria-expanded={isMenuOpen}
            aria-controls="mobile-menu"
          >
            {isMenuOpen ? <X size={24} /> : <Menu size={24} />}
          </Button>
        </div>

        {/* Mobile Navigation */}
        {isMenuOpen && (
          <div id="mobile-menu" className="md:hidden mt-4 pb-4 border-t border-white/20 pt-4" role="navigation" aria-label="Mobile navigation">
            <div className="flex flex-col space-y-4">
              <button
                onClick={() => scrollToSection("home")}
                className="text-white/90 hover:text-white transition-colors text-left"
              >
                Home
              </button>
              <button
                onClick={() => scrollToSection("features")}
                className="text-white/90 hover:text-white transition-colors text-left"
              >
                Features
              </button>
              <button
                onClick={() => scrollToSection("how-it-works")}
                className="text-white/90 hover:text-white transition-colors text-left"
              >
                How It Works
              </button>
              <button
                onClick={() => scrollToSection("about")}
                className="text-white/90 hover:text-white transition-colors text-left"
              >
                About
              </button>
              <button
                onClick={() => scrollToSection("blog")}
                className="text-white/90 hover:text-white transition-colors text-left"
              >
                Blog
              </button>
              <button
                onClick={() => scrollToSection("faq")}
                className="text-white/90 hover:text-white transition-colors text-left"
              >
                FAQ
              </button>
            </div>
          </div>
        )}
        
        {/* Header banner ad - hidden on mobile for better UX */}
        <div className="hidden sm:block mt-4">
          <AdBanner 
            adSlot="1234567800" 
            adFormat="horizontal"
            className="max-w-4xl mx-auto px-4"
            style={{ minHeight: '50px' }}
          />
        </div>
      </nav>
    </header>
  );
}